__all__ = ['topic', 'trace_elimination', 'music_score_recognition', 'speech_recognition_english',
           'speech_recognition_chinese', 'region_marquee', 'fluorescent_pen_recognition', 'photo_to_cartoon',
           'skin_recognition', 'watermark_removal', 'ocr_rec', 'paper_rotation', 'speech_synthesis', 'topic_loc',
           'teacher_qualification_check', 'object_detection', 'image_search', 'cutout_and_beauty',
           'idphoto_deep_beauty_to_b', 'gpu_accelerate', 'original_background_crop', 'title_detector', 'skin_quality',
           'wedding_photo_classic', 'image_handle_classic', 'face_info_classic']
